@@ -34,6 +34,7 @@ class Droplet(BaseAPI):
         ipv6: bool - True if ipv6 enabled
         private_networking: bool - True if private networking enabled
         user_data: str - arbitrary data to pass to droplet
+        volumes: [str] - list of blockstorage volumes
 
     Attributes returned by API:
         id: int - droplet id
@@ -56,6 +57,7 @@ class Droplet(BaseAPI):
         private_ip_address: str - private ip address
         ip_v6_address: [str] - list of ipv6 addresses assigned
         end_point: str - url of api endpoint used
+        volume_ids: [str] - list of blockstorage volumes
     """
 
     def __init__(self, *args, **kwargs):
@@ -86,6 +88,8 @@ class Droplet(BaseAPI):
         self.ipv6 = None
         self.private_networking = None
         self.user_data = None
+        self.volumes = []
+        self.tags = []
 
         # This will load also the values passed
         super(Droplet, self).__init__(*args, **kwargs)
@@ -186,6 +190,9 @@ class Droplet(BaseAPI):
             else:
                 self.private_networking = False
 
+        if "tags" in droplets:
+            self.tags = droplets["tags"]
+            
         return self
 
     def _perform_action(self, params, return_dict=True):
@@ -540,6 +547,7 @@ class Droplet(BaseAPI):
             "backups": bool(self.backups),
             "ipv6": bool(self.ipv6),
             "private_networking": bool(self.private_networking),
+            "volumes": self.volumes,
         }
 
         if self.user_data:
@@ -623,4 +631,4 @@ class Droplet(BaseAPI):
         return kernels
 
     def __str__(self):
-        return "%s %s" % (self.id, self.name)
+        return "<Droplet: %s %s>" % (self.id, self.name)
